/**
 * @file main.c
 * @author Jake G
 * @date 15 June 2024
 * @brief File contains the main function.
 *
 * This file contains the main logic loop and exists to setup the values
 * specific to the micro-controller. All other functions and configuration are
 * extracted into separate source files and headers for configuration.
 */

#include <stdio.h>
#define F_CPU 3333333UL

// This can prevent issues with utils/delay.h library with the gcc toolchain
#define __DELAY_BACKWARD_COMPATIBLE__

#include "RegEdit.h"
#include "Relays.h"
#include "SuperLoop.h"
#include "config.h"
#include "timer.h"
#include <avr/cpufunc.h> /* Required header file */
#include <avr/io.h>
#include <util/delay.h>

#define RELAY0_ENPIN (1 << 1) // PORTA
#define RELAY0_INPIN (1 << 3) // PORTA

#define RELAY1_ENPIN (1 << 3) // PORTB
#define RELAY1_INPIN (1 << 2) // PORTA

#define RELAY2_ENPIN (1 << 2) // PORTB
#define RELAY2_INPIN (1 << 0) // PORTB

// Set the function pointer for the delay func
void (*Delay_MicroSeconds)(double us) = _delay_us;

int main(int argc, char **argv) {
  Relay relay_array[3];

  // setup for the first relay
  relay_array[0].output_port = PORTA.OUT;
  relay_array[0].output_pin = RELAY0_ENPIN;
  relay_array[0].input_port = PORTA.IN;
  relay_array[0].input_pin = RELAY0_INPIN;

  // Setup for Infinite Loop
  SuperLoop_SetIterations(0);
  SuperLoop_Run();
}
